@@ -1,7 +1,7 @@
 /*
     Qalculate (library)
 
-    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna.knutsson@protonmail.com)
+    Copyright (C) 2003-2007, 2008, 2016-2021  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include <stdint.h>
 
 #define QALCULATE_MAJOR_VERSION (3)
-#define QALCULATE_MINOR_VERSION (15)
+#define QALCULATE_MINOR_VERSION (17)
 #define QALCULATE_MICRO_VERSION (0)
 
 static std::string empty_string;
@@ -398,7 +398,7 @@ static const struct PrintOptions {
 	int min_exp;
 	/// Number base for displaying numbers. Default: 10
 	int base;
-	/// How prefixes for numbers in non-decimal bases will be displayed
+	/// How prefixes for numbers in non-decimal bases will be displayed. Default: BASE_DISPLAY_NONE
 	BaseDisplay base_display;
 	/// Use lower case for non-numeric characters for bases > 10. Default: false
 	bool lower_case_numbers;
@@ -595,7 +595,10 @@ typedef enum {
 	/// In the "parse implicit multiplication first" mode, implicit multiplication is parsed before explicit multiplication (<quote>12/2(1+2) = 12/(2*3) = 2</quote>, <quote>5x/5y = (5*x)/(5*y) = x/y</quote>).
 	PARSING_MODE_IMPLICIT_MULTIPLICATION_FIRST,
 	/// In the conventional mode implicit multiplication does not differ from explicit multiplication (<quote>12/2(1+2) = 12/2*3 = 18</quote>, <quote>5x/5y = 5*x/5*y = xy</quote>).
-	PARSING_MODE_CONVENTIONAL
+	PARSING_MODE_CONVENTIONAL,
+	// as immediate execution mode in simple traditional calculators (e.g. 5+2*3=(5+2)*3=21)
+	PARSING_MODE_CHAIN,
+	PARSING_MODE_RPN
 } ParsingMode;
 
 typedef enum {
@@ -617,7 +620,7 @@ static const struct ParseOptions {
 	bool unknowns_enabled;
 	/// If units will be parsed. Default: true
 	bool units_enabled;
-	/// If Reverse Polish Notation syntax will be used. Default: false
+	/// If Reverse Polish Notation syntax will be used. Default: false (deprecated, use parsing_mode = PARSING_MODE_RPN instead)
 	bool rpn;
 	/// Base of parsed numbers. Default: 10
 	int base;
